#!/usr/bin/python
##### Razmerje G/T sprejemne postaje - S53MV 11.03.2018 #####

import math,numpy	#uporabljene funkcije

kn=1.03		#mnozilni korak risanja
nmin=0.1
nmax=20

tn=10		#temperatura neba
tz=290		#temperatura tal
tg=30		#temperatura sprejemnika

fd=0.7		#razmerje f/d zrcala
d=10		#premer zrcala 10 lambda
gts=(math.pi*d)**2	#skala razmerja G/T

u=[]		#polja za risanje grafa
v=[]
w=[]
x=[]
y=[]
z=[]
zz=[]

def alfa(fd):	#kot roba zrcala [rd]
	return 2*math.atan(0.25/fd)

def ftz(n,t):	#smerni diagram zarilca cos(t)^n
	return (math.cos(t))**n

def etas(n,fd):	#izracun izkoristka sevanja preko roba 0<etas<1
	kt=0.01*math.pi/2		#korak integracije
	t=kt/2
	a=alfa(fd)	#kot roba zrcala
	es=0
	esr=0
	while t<=math.pi/2:
		f=ftz(n,t)		#smerni diagram zarilca
		ff=f*f*math.sin(t)	#lamejev koef. sin(theta)
		esr=esr+ff		#referencna vsota
		if t<a:
			es=es+ff	#koristna vsota
		t=t+kt
	return es/esr

def etao(n,fd):	#izracun izkoristka osvetlitve odprtine 0<etao<1
	kr=0.01*0.25	#korak integracije
	ro2=kr/2
	p=0
	m=0
	a=0
	while ro2<0.25:
		z=0.25*ro2/fd			#visina zrcalne ploskve
		l=math.sqrt(ro2+(fd-z)**2)	#oddaljenost ploskve od gorisca
		t=math.asin(math.sqrt(ro2)/l)	#kot theta iz gorisca
		f=ftz(n,t)			#smerni diagram zarilca
		e=f*fd/l			#polje osvetlitve odprtine
		p=p+e		#integral polja
		m=m+e*e		#integral moci
		a=a+1		#integral povrsine
		ro2=ro2+kr
	return p*p/m/a

def uorz(n,fd):	#izracun upada osvetlitve na robu zrcala v dB
	lf=1+(0.25/fd)**2
	f=ftz(n,alfa(fd))
	return 20*math.log10(f/lf)

n=nmin
while n<=nmax:
	eo=etao(n,fd)		#izracun izkoristka osvetlitve odprtine
	v=v+[eo*100]		#risanje izkoristka osvetlitve odprtine [%]
	es=etas(n,fd)		#izracun izkoristka sevanja preko roba
	w=w+[es*100]		#risanje izkoristka sevanja preko roba [%]
	x=x+[es*eo*100]		#risanje skupnega izkoristka osvetlitve [%]
	ta=es*tn+(1-es)*tz	#izracun sumne temperature antene
	y=y+[ta]		#risanje sumne temperature antene [K]
	z=z+[es*eo/ta*gts]	#risanje razmerja G/Ta*gts [1/K]
	zz=zz+[es*eo/(ta+tg)*gts]	#risanje razmerja G/T*gts [1/K]
	u=u+[uorz(n,fd)]	#upad osvetlitve na robu zrcala [dB]
	n=n*kn			#pomnozi n za korak

print 'Eta_max',numpy.amax(x),'% @',u[numpy.argmax(x)],'dB'
print 'G/Ta_max',numpy.amax(z),'/K @',u[numpy.argmax(z)],'dB'
print 'G/T_max',numpy.amax(zz),'/K @',u[numpy.argmax(zz)],'dB'

import matplotlib.pyplot as plt		#risanje grafa funkcije
fig=plt.figure()
plt.plot(u,v,'c--')	#izkoristek osvetlitve odprtine [%]
plt.plot(u,w,'y--')	#izkoristek sevanja preko roba [%]
plt.plot(u,x,'g-')	#skupni izkoristek osvetlitve [%]
plt.plot(u,y,'r-')	#sumna temperatura antene [K]
plt.plot(u,z,'b-')	#razmerje G/Ta*gts [1/K]
plt.plot(u,zz,'m-')	#razmerje G/T*gts [1/K]
plt.axis([-40,0,0,110])
plt.title(r'Razmerji $G$/$T_A$ in $G$/$T$ zrcalne antene')
plt.xlabel(r'Upad osvetlitve na robu zrcala $a$ [dB]')
plt.grid(True)
fig.savefig('grafgt.svg', transparent=True)
plt.show()

#konec programa

